@@ -594,7 +594,7 @@ def quant_variable_study(data, col:str, bins: int = 50, epsilon: float = 0.0001,
 # --------------------- #
 # interactive scatterplot
 # --------------------- #
-def interactions(data):
+def interaction(data) -> None:
     # dataframe check 
     dataframe_review(data)
     # scatterplot function 
@@ -602,12 +602,52 @@ def interactions(data):
     def scatter(column1 = list(data.select_dtypes('number').columns), 
                 column2 = list(data.select_dtypes('number').columns)):
         # scatterplot
-        sn.regplot(x=data[column1], y=data[column2])
+        sn.jointplot(x=data[column1], y=data[column2], kind='scatter')
+        plt.show()
         
 # test 
 #interactions(X)
 
 
+# --------------------- #
+# interactive scatterplot barplot with hue for categorical, histplot with hue for quantitative
+# --------------------- #
+def inspection(data,threshold: int = 10, bins: int = 50, figsize: tuple[float, float] = (6., 4.)) -> None:
+    # dataframe check 
+    dataframe_review(data)
+    # plot step
+    @interact
+    def inspect(column = list(data.columns), target = list(data.columns)):
+        # useful info
+        title = ' ### Variable type info:'
+        display(Markdown(title))
+        column_type = str(data[column].describe().dtype)
+        target_type = str(data[target].describe().dtype)
+        string = f'**column**: {column_type}, **target**: {target_type}'
+        display(Markdown(string))
+        # check column variable type
+        if len(data[target].unique()) > threshold:
+            print('too many unique values in the target variable')
+        # check column variable type
+        elif data[column].dtypes == 'O':
+            #barplot 
+            plt.figure(figsize=figsize)
+            sn.countplot(x=data[column], hue=data[target])
+            plt.xticks(rotation=90)           
+            plt.show()
+        else:
+            # histplot
+            plt.figure(figsize=figsize)
+            try:
+                sn.histplot(x=data[column], hue=data[target], kde = True, bins = bins)
+            except:
+                sn.histplot(x=data[column], hue=data[target], bins = bins)
+            plt.show()
+    
+# test  
+#inspections(X)
+
+
 # --------------------- #
 # split and scale dataset
 # --------------------- #
